@@ -536,12 +536,12 @@ goodtags1
   = ["templatestyles", "includeonly", "references", "blockquote", "noinclude",
      "noframes", "frameset", "colgroup", "fieldset", "basefont",
      "!DOCTYPE", "noscript", "address", "acronym", "caption", "strong",
-     "applet", "script", "button", "select", "section", "legend", "footer",
+     "applet", "script", "button", "select", "section", "legend", "footer", "header",
      "strike", "object", "input", "center", "legend", "iframe", "small",
      "video", "audio", "style", "input", "label", "tbody", "thead",
-     "title", "track" ,"frame", "param", "base", "area", "font", "code", "span",
+     "title", "track" ,"frame", "param", "base", "area", "font", "code", "span", "main",
      "abbr", "body", "link", "menu", "math", "meta", "samp", "cite",
-     "head", "html", "poem", "form", "cite", "ref", "div", "pre", "sub",
+     "head", "html", "poem", "form", "cite", "ref", "div", "pre", "sub", "nav",
      "sup", "big", "del", "map", "bdo", "var", "dfn", "kbd", "col",
      "ins", "bdi", "dir", "img", "h1", "h2", "h3", "h4", "h5", "h6",
      "li", "ul", "ol", "tt", "dd", "dl", "dt", "hr", "em", "b", "i",
